==> 0.6.1-beta.tar.gz: android/src/main/java/com/quickblox/quickblox_sdk/auth/AuthModule.java <==

package com.quickblox.quickblox_sdk.auth;

import android.os.Bundle;
import android.text.TextUtils;

import com.quickblox.auth.session.QBSession;
import com.quickblox.auth.session.QBSessionManager;
import com.quickblox.core.QBEntityCallback;
import com.quickblox.core.exception.QBResponseException;
import com.quickblox.quickblox_sdk.base.BaseModule;
import com.quickblox.quickblox_sdk.utils.DateUtil;
import com.quickblox.users.QBUsers;
import com.quickblox.users.model.QBUser;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

///Created by Injoit on 2019-12-27.
///Copyright © 2019 Quickblox. All rights reserved.
public class AuthModule implements BaseModule {

    private static final String CHANNEL_NAME = "FlutterQBAuthChannel";

    private static final String LOGIN_METHOD = "login";
    private static final String LOGOUT_METHOD = "logout";
    private static final String SET_SESSION_METHOD = "setSession";
    private static final String GET_SESSION_METHOD = "getSession";

    @Override
    public void initEventHandler() {
        //empty
    }

    @Override
    public String getChannelName() {
        return CHANNEL_NAME;
    }

    @Override
    public MethodChannel.MethodCallHandler getMethodHandler() {
        return this::handleMethod;
    }

    @Override
    public void handleMethod(MethodCall methodCall, MethodChannel.Result result) {
        Map<String, Object> data = methodCall.arguments();
        switch (methodCall.method) {
            case LOGIN_METHOD:
                login(data, result);
                break;
            case LOGOUT_METHOD:
                logout(result);
                break;
            case SET_SESSION_METHOD:
                setSession(data, result);
                break;
            case GET_SESSION_METHOD:
                getSession(result);
        }
    }

    private void login(Map<String, Object> data, final MethodChannel.Result result) {
        String login = data != null && data.containsKey("login") ? (String) data.get("login") : null;
        String password = data != null && data.containsKey("password") ? (String) data.get("password") : null;

        QBUsers.signIn(login, password).performAsync(new QBEntityCallback<QBUser>() {
            @Override
            public void onSuccess(QBUser qbUser, Bundle bundle) {
                Map<String, Object> map = new HashMap<>();

                Map<String, Object> user = AuthMapper.qbUserToMap(qbUser);
                map.put("user", user);

                if (QBSessionManager.getInstance().getActiveSession() == null) {
                    result.error("The session doesn't exist", null, null);
                    return;
                }

                QBSessionManager.getInstance().getActiveSession().setUserId(qbUser.getId());
                QBSession qbSession = QBSessionManager.getInstance().getActiveSession();
                Map<String, Object> session = AuthMapper.qbSessionToMap(qbSession);
                map.put("session", session);

                result.success(map);
            }

            @Override
            public void onError(QBResponseException e) {
                result.error(e.getMessage(), null, null);
            }
        });
    }

    private void logout(final MethodChannel.Result result) {
        QBUsers.signOut().performAsync(new QBEntityCallback<Void>() {
            @Override
            public void onSuccess(Void aVoid, Bundle bundle) {
                result.success(aVoid);
            }

            @Override
            public void onError(QBResponseException e) {
                result.error(e.getMessage(), null, null);
            }
        });
    }

    private void setSession(Map<String, Object> data, final MethodChannel.Result result) {
        String token = data != null && data.containsKey("token") ? (String) data.get("token") : null;
        String expirationDate = data != null && data.containsKey("expirationDate") ?
                (String) data.get("expirationDate") : null;
        Integer userId = data != null && data.containsKey("userId") ? (Integer) data.get("userId") : null;
        Integer applicationId = data != null && data.containsKey("applicationId")
                ? (Integer) data.get("applicationId") : null;

        if (TextUtils.isEmpty(token)) {
            result.error("token is required", null, null);
            return;
        }
        if (TextUtils.isEmpty(expirationDate)) {
            result.error("expirationDate is required", null, null);
            return;
        }
        if (userId == null || userId <= 0) {
            result.error("userId is required", null, null);
            return;
        }
        if (applicationId == null || applicationId <= 0) {
            result.error("applicationId is required", null, null);
            return;
        }

        Date parsedExpirationDate = DateUtil.convertRawToDateISO(expirationDate);
        if (parsedExpirationDate == null) {
            result.error("expirationDate has a wrong format", null, null);
            return;
        }

        QBSessionManager.getInstance().createActiveSession(token, parsedExpirationDate);
        QBSession qbSession = QBSessionManager.getInstance().getActiveSession();

        qbSession.setUserId(userId);
        qbSession.setAppId(applicationId);

        Map<String, Object> session = AuthMapper.qbSessionToMap(qbSession);
        result.success(session);
    }

    private void getSession(final MethodChannel.Result result) {
        if (QBSessionManager.getInstance().getActiveSession() == null) {
            result.error("The session doesn't exist", null, null);
            return;
        }

        QBSession qbSession = QBSessionManager.getInstance().getActiveSession();
        Map<String, Object> session = AuthMapper.qbSessionToMap(qbSession);
        result.success(session);
    }
}

==> 0.6.5-beta.tar.gz: android/src/main/java/com/quickblox/quickblox_sdk/auth/AuthModule.java <==

package com.quickblox.quickblox_sdk.auth;

import android.os.Bundle;
import android.text.TextUtils;

import com.quickblox.auth.session.QBSession;
import com.quickblox.auth.session.QBSessionManager;
import com.quickblox.core.QBEntityCallback;
import com.quickblox.core.exception.QBResponseException;
import com.quickblox.quickblox_sdk.base.BaseModule;
import com.quickblox.quickblox_sdk.utils.DateUtil;
import com.quickblox.users.QBUsers;
import com.quickblox.users.model.QBUser;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

///Created by Injoit on 2019-12-27.
///Copyright © 2019 Quickblox. All rights reserved.
public class AuthModule implements BaseModule {

    private static final String CHANNEL_NAME = "FlutterQBAuthChannel";

    private static final String LOGIN_METHOD = "login";
    private static final String LOGOUT_METHOD = "logout";
    private static final String SET_SESSION_METHOD = "setSession";
    private static final String GET_SESSION_METHOD = "getSession";

    @Override
    public void initEventHandler() {
        //empty
    }

    @Override
    public String getChannelName() {
        return CHANNEL_NAME;
    }

    @Override
    public MethodChannel.MethodCallHandler getMethodHandler() {
        return this::handleMethod;
    }

    @Override
    public void handleMethod(MethodCall methodCall, MethodChannel.Result result) {
        Map<String, Object> data = methodCall.arguments();
        switch (methodCall.method) {
            case LOGIN_METHOD:
                login(data, result);
                break;
            case LOGOUT_METHOD:
                logout(result);
                break;
            case SET_SESSION_METHOD:
                setSession(data, result);
                break;
            case GET_SESSION_METHOD:
                getSession(result);
        }
    }

    private void login(Map<String, Object> data, final MethodChannel.Result result) {
        String login = data != null && data.containsKey("login") ? (String) data.get("login") : null;
        String password = data != null && data.containsKey("password") ? (String) data.get("password") : null;

        QBUsers.signIn(login, password).performAsync(new QBEntityCallback<QBUser>() {
            @Override
            public void onSuccess(QBUser qbUser, Bundle bundle) {
                Map<String, Object> map = new HashMap<>();

                Map<String, Object> user = AuthMapper.qbUserToMap(qbUser);
                map.put("user", user);

                if (QBSessionManager.getInstance().getActiveSession() == null) {
                    result.error("The session doesn't exist", null, null);
                    return;
                }

                QBSessionManager.getInstance().getActiveSession().setUserId(qbUser.getId());
                QBSession qbSession = QBSessionManager.getInstance().getActiveSession();
                Map<String, Object> session = AuthMapper.qbSessionToMap(qbSession);
                map.put("session", session);

                result.success(map);
            }

            @Override
            public void onError(QBResponseException e) {
                result.error(e.getMessage(), null, null);
            }
        });
    }

    private void logout(final MethodChannel.Result result) {
        QBUsers.signOut().performAsync(new QBEntityCallback<Void>() {
            @Override
            public void onSuccess(Void aVoid, Bundle bundle) {
                result.success(aVoid);
            }

            @Override
            public void onError(QBResponseException e) {
                result.error(e.getMessage(), null, null);
            }
        });
    }

    private void setSession(Map<String, Object> data, final MethodChannel.Result result) {
        String token = data != null && data.containsKey("token") ? (String) data.get("token") : null;
        Integer userId = data != null && data.containsKey("userId") ? (Integer) data.get("userId") : null;
        Integer applicationId = data != null && data.containsKey("applicationId")
                ? (Integer) data.get("applicationId") : null;

        if (TextUtils.isEmpty(token)) {
            result.error("token is required", null, null);
            return;
        }
        if (userId == null || userId <= 0) {
            result.error("userId is required", null, null);
            return;
        }
        if (applicationId == null || applicationId <= 0) {
            result.error("applicationId is required", null, null);
            return;
        }

        Date tokenExpirationDate = DateUtil.generateFutureDate();

        QBSessionManager.getInstance().createActiveSession(token, tokenExpirationDate);
        QBSession qbSession = QBSessionManager.getInstance().getActiveSession();

        qbSession.setUserId(userId);
        qbSession.setAppId(applicationId);

        Map<String, Object> session = AuthMapper.qbSessionToMap(qbSession);
        result.success(session);
    }

    private void getSession(final MethodChannel.Result result) {
        if (QBSessionManager.getInstance().getActiveSession() == null) {
            result.error("The session doesn't exist", null, null);
            return;
        }

        QBSession qbSession = QBSessionManager.getInstance().getActiveSession();
        Map<String, Object> session = AuthMapper.qbSessionToMap(qbSession);
        result.success(session);
    }
}
